Crate eipw_preamble

Crate eipw_preamble 

This crate comprises the preamble parsing logic for eipw, the EIP validator.

See Preamble for more details.

Structs

Field
A field from a Preamble that includes its position in a source file.
ParseErrors
Errors that can arise while parsing a preamble. See [`Preamble::parse’].
Preamble
An ordered list of fields from a preamble.

Enums

SplitError
Errors that can arise from Preamble::split.